Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AHandler ¶
type AHandler struct {
DoneCh chan struct{}
OutputCh chan string
// contains filtered or unexported fields
}
AHandler is responsible for keeping a token alive and renewed and passing new tokens to the sink server
func NewAHandler ¶
func NewAHandler(conf *AHandlerConfig) *AHandler
type AHandlerConfig ¶
Click to show internal directories.
Click to hide internal directories.